# K_DeZero

## Overview

This library is an my improved version of "Deep Learning from Basic 3".
(In production)

## Requirement

- Python3.8
- For details, see requirements.txt

## Usage

```
git clone https://github.com/kotabrog/K_DeZero.git
cd kdezero
python setup.py sdist
pip install dist\kdezero-1.5.tar.gz
```

This will install the library "kdezero".

## sample

Soon.

## Features

Soon.

## Author

[twitter](https://twitter.com/Kotabrog)

## Licence

[MIT](https://github.com/kotabrog/Libasm/blob/main/LICENSE)
